# worldtimebuddy
Get current time for all possible timezone using CLI (exclusively for developers)

```
Usage: worldtimebuddy [OPTIONS]

  Display current time for all timezones, major timezones, or a specific
  timezone.

Options:
  --format TEXT         DateTime format string
  --major               Show only major timezones
  -tz, --timezone TEXT  Show time for a specific timezone
  --list                List all available timezones
  --help                Show this message and exit.
```